==> icons-foundation-1.0.5.tgz: package/README.md <==
# Foundation

This package includes individual files for each icon, ready to be imported into a project.

Each icon is in its own file, so you can bundle several icons from different icon sets without bundling entire icon sets.

## Installation

If you are using NPM:

```bash
npm install @iconify/icons-foundation --save-dev
```

If you are using Yarn:

```bash
yarn add --dev @iconify/icons-foundation
```

## Usage with React

First you need to install [Iconify for React](https://github.com/iconify/iconify/packages/react).

If you are using NPM:

```bash
npm install --save-dev @iconify/react
```

If you are using Yarn:

```bash
yarn add --dev @iconify/react
```

### Example using icon 'graph-trend' with React

```js
import { Icon, InlineIcon } from '@iconify/react';
import graphTrend from '@iconify/icons-foundation/graph-trend';
```

```jsx
<Icon icon={graphTrend} />
<p>This is some text with icon adjusted for baseline: <InlineIcon icon={graphTrend} /></p>
```

### Example using icon 'indent-more' with React

```js
import { Icon, InlineIcon } from '@iconify/react';
import indentMore from '@iconify/icons-foundation/indent-more';
```

```jsx
<Icon icon={indentMore} />
<p>This is some text with icon adjusted for baseline: <InlineIcon icon={indentMore} /></p>
```

### Example using icon 'lock' with React

```js
import { Icon, InlineIcon } from '@iconify/react';
import lockIcon from '@iconify/icons-foundation/lock';
```

```jsx
<Icon icon={lockIcon} />
<p>This is some text with icon adjusted for baseline: <InlineIcon icon={lockIcon} /></p>
```

See https://github.com/iconify/iconify/packages/react for details.

## Usage with Vue

First you need to install [Iconify for Vue](https://github.com/iconify/iconify/packages/vue).

If you are using NPM:

```bash
npm install --save-dev @iconify/vue
```

If you are using Yarn:

```bash
yarn add --dev @iconify/vue
```

### Example using icon 'graph-trend' with Vue

This example is using object syntax with TypeScript.

```vue
<template>
	<p>
		<iconify-icon :icon="icons.graphTrend" />
	</p>
</template>

<script lang="ts">
import { Component, Prop, Vue } from 'vue-property-decorator';
import IconifyIcon from '@iconify/vue';
import graphTrend from '@iconify/icons-foundation/graph-trend';

export default Vue.extend({
	components: {
		IconifyIcon,
	},
	data() {
		return {
			icons: {
				graphTrend: graphTrend,
			},
		};
	},
});
</script>
```

### Example using icon 'indent-more' with Vue

This example is using string syntax.

```vue
<template>
	<p>
		Example of 'indent-more' icon:
		<iconify-icon icon="indentMore" :inline="true" />!
	</p>
</template>

<script>
import IconifyIcon from '@iconify/vue';
import indentMore from '@iconify/icons-foundation/indent-more';

IconifyIcon.addIcon('indentMore', indentMore);

export default {
	components: {
		IconifyIcon,
	},
};
</script>
```

### Example using icon 'lock' with Vue

This example is using object syntax.

```vue
<template>
	<iconify-icon :icon="icons.lockIcon" />
</template>

<script>
import IconifyIcon from '@iconify/vue';
import lockIcon from '@iconify/icons-foundation/lock';

export default {
	components: {
		IconifyIcon,
	},
	data() {
		return {
			icons: {
				lockIcon,
			},
		};
	},
};
</script>
```

See https://github.com/iconify/iconify/packages/vue for details.

## About Foundation

Icons author: Zurb

Website: https://github.com/zurb/foundation-icon-fonts

License: MIT

==> icons-foundation-1.1.0.tgz: package/README.md <==
# Foundation

This package includes individual files for each icon, ready to be imported into a project.

Each icon is in its own file, so you can bundle several icons from different icon sets without bundling entire icon sets.

## Installation

If you are using NPM:

```bash
npm install @iconify/icons-foundation --save-dev
```

If you are using Yarn:

```bash
yarn add --dev @iconify/icons-foundation
```

## Usage with React

First you need to install [Iconify for React](https://github.com/iconify/iconify/packages/react).

If you are using NPM:

```bash
npm install --save-dev @iconify/react
```

If you are using Yarn:

```bash
yarn add --dev @iconify/react
```

### Example using icon 'graph-trend' with React

```js
import { Icon, InlineIcon } from '@iconify/react';
import graphTrend from '@iconify/icons-foundation/graph-trend';
```

```jsx
<Icon icon={graphTrend} />
<p>This is some text with icon adjusted for baseline: <InlineIcon icon={graphTrend} /></p>
```

### Example using icon 'indent-more' with React

This example is using string syntax that is available since Iconify for React 2.0

This example will not work with Iconify for React 1.x

```jsx
import React from 'react';
import { Icon, addIcon } from '@iconify/react';
import indentMore from '@iconify/icons-foundation/indent-more';

addIcon('indentMore', indentMore);

export function MyComponent() {
	return (
		<div>
			<Icon icon="indentMore" />
		</div>
	);
}
```

### Example using icon 'lock' with React

```jsx
import React from 'react';
import { InlineIcon } from '@iconify/react';
import lockIcon from '@iconify/icons-foundation/lock';

export function MyComponent() {
	return (
		<p>
			<InlineIcon icon={lockIcon} /> Sample text with an icon.
		</p>
	);
}
```

See https://github.com/iconify/iconify/packages/react for details.

## Usage with Vue

First you need to install [Iconify for Vue](https://github.com/iconify/iconify/packages/vue).

If you are using NPM:

```bash
npm install --save-dev @iconify/vue
```

If you are using Yarn:

```bash
yarn add --dev @iconify/vue
```

### Example using icon 'graph-trend' with Vue

This example is using object syntax with TypeScript.

```vue
<template>
	<p>
		<iconify-icon :icon="icons.graphTrend" />
	</p>
</template>

<script lang="ts">
import { Component, Prop, Vue } from 'vue-property-decorator';
import IconifyIcon from '@iconify/vue';
import graphTrend from '@iconify/icons-foundation/graph-trend';

export default Vue.extend({
	components: {
		IconifyIcon,
	},
	data() {
		return {
			icons: {
				graphTrend: graphTrend,
			},
		};
	},
});
</script>
```

### Example using icon 'indent-more' with Vue

This example is using string syntax.

```vue
<template>
	<p>
		Example of 'indent-more' icon:
		<iconify-icon icon="indentMore" :inline="true" />!
	</p>
</template>

<script>
import IconifyIcon from '@iconify/vue';
import indentMore from '@iconify/icons-foundation/indent-more';

IconifyIcon.addIcon('indentMore', indentMore);

export default {
	components: {
		IconifyIcon,
	},
};
</script>
```

### Example using icon 'lock' with Vue

This example is using object syntax.

```vue
<template>
	<iconify-icon :icon="icons.lockIcon" />
</template>

<script>
import IconifyIcon from '@iconify/vue';
import lockIcon from '@iconify/icons-foundation/lock';

export default {
	components: {
		IconifyIcon,
	},
	data() {
		return {
			icons: {
				lockIcon,
			},
		};
	},
};
</script>
```

See https://github.com/iconify/iconify/packages/vue for details.

## Usage with Svelte

First you need to install [Iconify for Svelte](https://github.com/iconify/iconify/packages/svelte).

If you are using NPM:

```bash
npm install --save-dev @iconify/svelte
```

If you are using Yarn:

```bash
yarn add --dev @iconify/svelte
```

### Example using icon 'graph-trend' with Svelte

```svelte
<script>
    // npm install --save-dev @iconify/svelte @iconify/icons-foundation
    import IconifyIcon from '@iconify/svelte';
    import graphTrend from '@iconify/icons-foundation/graph-trend';
</script>

<IconifyIcon icon={graphTrend} />
```

### Example using icon 'indent-more' with Svelte

```svelte
<script>
    // npm install --save-dev @iconify/svelte @iconify/icons-foundation
    import IconifyIcon from '@iconify/svelte';
    import indentMore from '@iconify/icons-foundation/indent-more';
</script>

<IconifyIcon icon={indentMore} />
```

### Example using icon 'lock' with Svelte

```svelte
<script>
    // npm install --save-dev @iconify/svelte @iconify/icons-foundation
    import IconifyIcon from '@iconify/svelte';
    import lockIcon from '@iconify/icons-foundation/lock';
</script>

<IconifyIcon icon={lockIcon} />
```

See https://github.com/iconify/iconify/packages/svelte for details.

## About Foundation

Icons author: Zurb

Website: https://github.com/zurb/foundation-icon-fonts

License: MIT
